@@ -14,7 +14,9 @@ class App:
     ExtensionContainer = 'App::ExtensionContainer'
     FeaturePython = 'App::FeaturePython'
     FeatureTest = 'App::FeatureTest'
+    FeatureTestColumn = 'App::FeatureTestColumn'
     FeatureTestException = 'App::FeatureTestException'
+    FeatureTestPlacement = 'App::FeatureTestPlacement'
     FunctionExpression = 'App::FunctionExpression'
     GeoFeature = 'App::GeoFeature'
     GeoFeatureGroupExtension = 'App::GeoFeatureGroupExtension'
@@ -224,7 +226,9 @@ class Common:
     voidDownloadItem = 'voidDownloadItem'
     voidE57XmlParser = 'voidE57XmlParser'
     voidExpressionCompleter = 'voidExpressionCompleter'
+    voidLineGroup = 'voidLineGroup'
     voidLyingOnGeom = 'voidLyingOnGeom'
+    voidPATLineSpec = 'voidPATLineSpec'
     voidType = 'voidType'
     voidView3DInventorViewer = 'voidView3DInventorViewer'
     voidWorkflowManager = 'voidWorkflowManager'
@@ -1088,6 +1092,10 @@ class WebGui:
     Workbench = 'WebGui::Workbench'
 
 
+class voidApp:
+    Extension = 'voidApp::Extension'
+
+
 class voidGui:
     SoFCDB = 'voidGui::SoFCDB'
 
